# Generated by Django 3.2 on 2022-07-27 13:50

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("drf_file_upload", "0003_auto_20210420_2323"),
    ]

    operations = [
        migrations.AddField(
            model_name="anonymousuploadedfile",
            name="name",
            field=models.CharField(editable=False, max_length=254, null=True),
        ),
        migrations.AddField(
            model_name="anonymousuploadedfile",
            name="size",
            field=models.PositiveBigIntegerField(editable=False, null=True),
        ),
        migrations.AddField(
            model_name="authenticateduploadedfile",
            name="name",
            field=models.CharField(editable=False, max_length=254, null=True),
        ),
        migrations.AddField(
            model_name="authenticateduploadedfile",
            name="size",
            field=models.PositiveBigIntegerField(editable=False, null=True),
        ),
    ]
