# Generated by Django 3.2 on 2021-04-20 21:23

import uuid

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("drf_file_upload", "0002_authenticateduploadedfile_uuid"),
    ]

    operations = [
        migrations.AlterField(
            model_name="anonymousuploadedfile",
            name="uuid",
            field=models.UUIDField(default=uuid.uuid4, editable=False, unique=True),
        ),
        migrations.AlterField(
            model_name="authenticateduploadedfile",
            name="uuid",
            field=models.UUIDField(default=uuid.uuid4, editable=False, unique=True),
        ),
    ]
